Package: latex2exp
Type: Package
Title: Use LaTeX Expressions in Plots
Version: 0.9.7
Date: 2022-12-28
Authors@R: person("Stefano", "Meschiari", email="stefano.meschiari@gmail.com", role=c("aut", "cre"))
Description: Parses and converts LaTeX math formulas to R's plotmath
    expressions, used to enter mathematical formulas and symbols to be rendered as
    text, axis labels, etc. throughout R's plotting system.
License: MIT + file LICENSE
URL: https://www.stefanom.io/latex2exp/,
        https://github.com/stefano-meschiari/latex2exp
BugReports: https://github.com/stefano-meschiari/latex2exp/issues
Imports: stringr, magrittr
Encoding: UTF-8
Suggests: testthat, waldo, knitr, ggplot2, rmarkdown, purrr, tibble,
        reactable, htmltools, RCurl, rlang, dplyr
VignetteBuilder: knitr
RoxygenNote: 7.2.2
Language: en-US
Author: Stefano Meschiari [aut, cre]
Maintainer: Stefano Meschiari <stefano.meschiari@gmail.com>
Built: R 4.4.0; ; 2024-04-28 19:08:35 UTC; unix
