Package: latex2exp
Type: Package
Title: Use LaTeX Expressions in Plots
Version: 0.9.6
Date: 2022-11-27
Authors@R: person("Stefano", "Meschiari", email="stefano.meschiari@gmail.com", role=c("aut", "cre"))
Description: Parses and converts LaTeX math formulas to R's plotmath
    expressions, used to enter mathematical formulas and symbols to be rendered as
    text, axis labels, etc. throughout R's plotting system.
License: MIT + file LICENSE
URL: https://www.stefanom.io/latex2exp/,
        https://github.com/stefano-meschiari/latex2exp
BugReports: https://github.com/stefano-meschiari/latex2exp/issues
Imports: stringr, magrittr
Encoding: UTF-8
Suggests: testthat, waldo, knitr, ggplot2, rmarkdown, purrr, tibble,
        reactable, htmltools, RCurl, rlang, dplyr
VignetteBuilder: knitr
RoxygenNote: 7.1.2
Language: en-US
NeedsCompilation: no
Packaged: 2022-11-28 01:32:27 UTC; stefano
Author: Stefano Meschiari [aut, cre]
Maintainer: Stefano Meschiari <stefano.meschiari@gmail.com>
Repository: CRAN
Date/Publication: 2022-11-28 03:30:02 UTC
Built: R 4.5.2; ; 2026-04-22 19:18:21 UTC; unix
