# Generated by roxygen2: do not edit by hand

S3method(plot,expression)
S3method(print,latexexpression)
S3method(print,latextoken2)
export(TeX)
export(latex2exp)
export(latex2exp_examples)
export(latex2exp_supported)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,text)
importFrom(magrittr,"%>%")
importFrom(stringr,fixed)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_length)
importFrom(stringr,str_match)
importFrom(stringr,str_match_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_starts)
importFrom(stringr,str_sub)
importFrom(stringr,str_trim)
importFrom(utils,vignette)
